@@ -342,9 +342,7 @@ p contains "B" if {
 				if bundleType.tar {
 					files["bundle.tar"] = ""
 				} else {
-					for k, v := range tc.files {
-						files[k] = v
-					}
+					maps.Copy(files, tc.files)
 				}
 
 				test.WithTestFS(tc.files, false, func(root string, fsys fs.FS) {
@@ -414,7 +412,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 					Manifest: bundle.Manifest{
 						Roots: &[]string{"a"},
 					},
-					Data:    map[string]interface{}{},
+					Data:    map[string]any{},
 					Modules: []bundle.ModuleFile{},
 				},
 			},
@@ -429,7 +427,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						Roots:       &[]string{"a"},
 						RegoVersion: &regoV1,
 					},
-					Data:    map[string]interface{}{},
+					Data:    map[string]any{},
 					Modules: []bundle.ModuleFile{},
 				},
 			},
@@ -443,14 +441,14 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 					Manifest: bundle.Manifest{
 						Roots: &[]string{"a"},
 					},
-					Data:    map[string]interface{}{},
+					Data:    map[string]any{},
 					Modules: []bundle.ModuleFile{},
 				},
 				{
 					Manifest: bundle.Manifest{
 						Roots: &[]string{"b"},
 					},
-					Data:    map[string]interface{}{},
+					Data:    map[string]any{},
 					Modules: []bundle.ModuleFile{},
 				},
 			},
@@ -465,7 +463,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						Roots:       &[]string{"a"},
 						RegoVersion: &regoV1,
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path:         "a/test1.rego",
@@ -480,7 +478,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						Roots:       &[]string{"b"},
 						RegoVersion: &regoV1,
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path:         "b/test1.rego",
@@ -507,7 +505,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						Roots:       &[]string{"a"},
 						RegoVersion: &regoV0,
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path:         "a/test1.rego",
@@ -522,7 +520,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						Roots:       &[]string{"b"},
 						RegoVersion: &regoV0,
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path:         "b/test1.rego",
@@ -549,7 +547,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						Roots:       &[]string{"a"},
 						RegoVersion: &regoV0,
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path:         "a/test1.rego",
@@ -564,7 +562,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						Roots:       &[]string{"b"},
 						RegoVersion: &regoV1,
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path:         "b/test1.rego",
@@ -590,7 +588,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						Roots:       &[]string{"a"},
 						RegoVersion: &regoV1,
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path:         "a/test1.rego",
@@ -614,7 +612,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 							"/test1.rego": 0,
 						},
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							// we don't expect this file to get an individual rego-version in the result, as
@@ -637,7 +635,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 						RegoVersion: &regoV0,
 						Roots:       &[]string{"c"},
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						// we don't expect these files to get individual rego-versions in the result,
 						// as they have the same rego-version as the global rego-version
@@ -677,7 +675,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 							"a/*": 1,
 						},
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path: "a/foo/test.rego",
@@ -705,7 +703,7 @@ func TestCompilerBundleMergeWithBundleRegoVersion(t *testing.T) {
 							"*/bar/*": 0,
 						},
 					},
-					Data: map[string]interface{}{},
+					Data: map[string]any{},
 					Modules: []bundle.ModuleFile{
 						{
 							Path: "b/foo/test.rego",
